@@ -3,6 +3,13 @@ from asyncio import AbstractEventLoop, get_event_loop
 
 import uuid
 import warnings
+
+try:
+    import betterproto
+except:
+    betterproto = None
+
+from google.protobuf.reflection import GeneratedProtocolMessageType
 from google.protobuf.struct_pb2 import Struct
 from google.protobuf.wrappers_pb2 import BytesValue, StringValue
 from typing import Tuple, Mapping, Any, Callable, Union
@@ -123,11 +130,16 @@ class PatchworkPublisher(Component):
         if isinstance(payload, str):
             wrapper = StringValue(value=payload)
             task.payload.pack(wrapper)
-        if isinstance(payload, bytes):
+        elif isinstance(payload, bytes):
             wrapper = BytesValue(value=payload)
             task.payload.Pack(wrapper)
-        else:
+        elif isinstance(payload, GeneratedProtocolMessageType):
             task.payload.Pack(payload)
+        elif betterproto is not None and isinstance(payload, betterproto.Message):
+            task.payload.type_url = f'betterproto.{payload.__class__.__name__}'
+            task.payload.value = bytes(payload)
+        else:
+            raise ValueError('unsupported payload type')
 
         if 'not_before' in meta:
             task.meta.not_before = meta.pop('not_before')
