@@ -128,6 +128,8 @@ class AsyncLocalBroker:
         For development purposes only!
     """
 
+    __default = []
+
     def __init__(
             self,
             initial_queues: Iterable[str] = tuple(),
@@ -145,6 +147,13 @@ class AsyncLocalBroker:
         for q_name in initial_queues:
             self._create_queue(q_name)
 
+    @classmethod
+    def default(cls):
+        if not cls.__default:
+            cls.__default.append(cls())
+
+        return cls.__default[0]
+
     def _create_queue(self, name):
         self._queues[name] = Topic(maxsize=self._queue_size)
         if name in self._missing_notif:
@@ -247,6 +256,9 @@ class AsyncLocalPublisher(AsyncPublisher):
         :param queue:   asyncio queue to bind to
         """
         super().__init__(parent=parent, **options)
+        if broker is None:
+            broker = AsyncLocalBroker.default()
+
         self._broker = broker
 
     def __repr__(self):
@@ -258,7 +270,6 @@ class AsyncLocalPublisher(AsyncPublisher):
         return self._broker
 
     async def _start(self):
-        assert self._broker is not None, "no broker specified"
         self.logger.debug(f"Publisher attached to broker {self._broker}")
 
     async def _stop(self):
@@ -284,6 +295,9 @@ class AsyncLocalSubscriber(AsyncSubscriber):
         """
         :param queue:   asyncio queue to bind to
         """
+        if broker is None:
+            broker = AsyncLocalBroker.default()
+
         self._broker = broker
         super().__init__(parent=parent, **options)
         self.uncommitted = set()
@@ -298,7 +312,6 @@ class AsyncLocalSubscriber(AsyncSubscriber):
         return self._broker
 
     async def _start(self):
-        assert self._broker is not None, "no broker specified"
         self.logger.debug(f"Subscriber attached to broker {self._broker}")
         if not self.settings.queue_names:
             warnings.warn(f'{self.__class__.__name__}: no queues to listen on')
