@@ -76,6 +76,26 @@ async def test_send_timeout():
         task.meta.queue_name = 'test'
         await client._send(b'payload', task, timeout=0.01)
 
+
+@pytest.mark.asyncio
+async def test_shared_default_queue():
+    """
+    Test if all local async client instances share the same default broker instance
+    :return:
+    """
+    client_1 = AsyncLocalPublisher()
+    client_2 = AsyncLocalSubscriber(queue_names=['test'])
+
+    task = Task()
+    task.meta.queue_name = 'test'
+    await client_1._send(b'payload', task)
+    async with client_2:
+        payload, meta = await client_2._fetch_one()
+
+    assert payload == b'payload'
+    assert meta == {}
+
+
 @pytest.mark.asyncio
 async def test_fetch_one(subscriber, broker):
     broker.get_queue('test').put_nowait(b'payload')
